/* eslint-disable react/jsx-max-props-per-line */
/* eslint-disable prefer-const */
/* eslint-disable react/jsx-handler-names */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

export class DropdownItem extends Component {
	constructor(props) {
		super(props);
		this.onClick = this.onClick.bind(this);
	}

	onClick(event) {
		const { onClick, option } = this.props;
		if (onClick) {
			onClick({
				originalEvent: event,
				option,
			});
		}
	}

	render() {
		const {
			ariaLabel,
			dataKey,
			disabled,
			handleInputKeyDown,
			index,
			label,
			option,
			parentId,
			selected,
			template,
		} = this.props;
		let className = classNames('p-dropdown-item', {
			'p-highlight': selected,
			'p-disabled': disabled,
			'p-dropdown-item-empty': !label || label.length === 0,
		});
		let content = template ? template(option) : label;

		return (
			<li
				id={`${parentId}-item-${option[dataKey] ? option[dataKey] : index}`}
				tabIndex={index + 2}
				role="listitem"
				className={className}
				onClick={this.onClick}
				onKeyDown={handleInputKeyDown}
				aria-label={ariaLabel}
			>
				{content}
			</li>
		);
	}
}

DropdownItem.defaultProps = {
	option: null,
	label: null,
	template: null,
	selected: false,
	disabled: false,
	onClick: null,
};

DropdownItem.propTypes = {
	ariaLabel: PropTypes.string,
	dataKey: PropTypes.string,
	disabled: PropTypes.bool,
	handleInputKeyDown: PropTypes.func,
	index: PropTypes.number,
	label: PropTypes.any,
	onClick: PropTypes.func,
	option: PropTypes.object,
	parentId: PropTypes.string,
	selected: PropTypes.bool,
	template: PropTypes.func,
};

export default DropdownItem;
